window.Gleam.initSearch([{"doc":"gleamy_bench","title":"gleamy_bench","content":"# gleamy_bench\n\n[![Package Version](https://img.shields.io/hexpm/v/gleamy_bench)](https://hex.pm/packages/gleamy_bench)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/gleamy_bench/)\n\nA library for benchmarking gleam code.\n\n# How To\n\n```rust\nimport gleamy_bench.{Bench, BenchTime, Function, IPS, Input, Min, P, run, table}\n\n// ..\n\nBench(\n    [\n        Input(&quot;n=5&quot;, 5),\n        Input(&quot;n=10&quot;, 10),\n        Input(&quot;n=15&quot;, 15),\n    ],\n    [\n        Function(&quot;fib1&quot;, fib1),\n        Function(&quot;fib2&quot;, fib2),\n    ],\n)\n|&gt; run([BenchTime(500)])\n|&gt; table([IPS, Min, P(99)])\n|&gt; io.println()\n\n```\n\nA benchmark is defined by giving a list of inputs and a list of functions to run on those inputs. Each input + function combination will be timed.\n\nThe inputs should all be the same type, and the functions should all accept that type as the only argument. The return type of the function does not matter, only that they all return the same type.\n\nThe `run` function actually runs the benchmark and collects the results. It accepts a list of options to change default behaviour, for example `BenchTime(100)` can be used to change how long each function is run repeatedly when collecting results (in milliseconds).\n\nThe `table` function makes a table out of the results. You can choose the list of statistics you would like to include in the table.\n\nThe output for this example looks like the following.\n\n```\nInput                   Function                           IPS             Min             P99\nn=5                     fib1                      2236277.3002          0.0002          0.0006\nn=5                     fib2                      2493122.7461          0.0002          0.0006\nn=10                    fib1                       750561.7961          0.0010          0.0022\nn=10                    fib2                      2755751.7477          0.0002          0.0005\nn=15                    fib1                        80833.4127          0.0102          0.0184\nn=15                    fib2                      2139409.1371          0.0003          0.0007\n```\n\n## Contributing\n\nSuggestions and pull requests are welcome!\n\n## Quick start\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\ngleam shell # Run an Erlang shell\n```\n\n## Installation\n\nIf available on Hex this package can be added to your Gleam project:\n\n```sh\ngleam add gleamy_bench\n```\n\nand its documentation can be found at &lt;https://hexdocs.pm/gleamy_bench&gt;.\n","url":"index.html"},{"doc":"gleamy_bench","title":"Bench","content":"pub type Bench(a, b) {\n  Bench(inputs: List(Input(a)), functions: List(Function(a, b)))\n}\n\nBench(inputs: List(Input(a)), functions: List(Function(a, b)))\n\n\nSynonyms:\ngleamy_bench.Bench\ngleamy_bench Bench","url":"gleamy_bench.html#Bench"},{"doc":"gleamy_bench","title":"Function","content":"pub type Function(a, b) {\n  Function(label: String, function: fn(a) -&gt; b)\n}\n\nFunction(label: String, function: fn(a) -&gt; b)\n\n\nSynonyms:\ngleamy_bench.Function\ngleamy_bench Function","url":"gleamy_bench.html#Function"},{"doc":"gleamy_bench","title":"Input","content":"pub type Input(a) {\n  Input(label: String, value: a)\n}\n\nInput(label: String, value: a)\n\n\nSynonyms:\ngleamy_bench.Input\ngleamy_bench Input","url":"gleamy_bench.html#Input"},{"doc":"gleamy_bench","title":"Option","content":"pub type Option {\n  WarmupTime(ms: Int)\n  BenchTime(ms: Int)\n}\n\nWarmupTime(ms: Int)\n\n\nBenchTime(ms: Int)\n\n\nSynonyms:\ngleamy_bench.Option\ngleamy_bench Option","url":"gleamy_bench.html#Option"},{"doc":"gleamy_bench","title":"Set","content":"pub type Set {\n  Set(input: String, function: String, reps: List(Float))\n}\n\nSet(input: String, function: String, reps: List(Float))\n\n\nSynonyms:\ngleamy_bench.Set\ngleamy_bench Set","url":"gleamy_bench.html#Set"},{"doc":"gleamy_bench","title":"Stat","content":"pub type Stat {\n  P(Int)\n  IPS\n  Min\n  Max\n  Mean\n  SD\n  SDPercent\n  Stat(name: String, calculate: fn(Set) -&gt; Float)\n}\n\nP(Int)\n\n\nIPS\n\n\nMin\n\n\nMax\n\n\nMean\n\n\nSD\n\n\nSDPercent\n\n\nStat(name: String, calculate: fn(Set) -&gt; Float)\n\n\nSynonyms:\ngleamy_bench.Stat\ngleamy_bench Stat","url":"gleamy_bench.html#Stat"},{"doc":"gleamy_bench","title":"do_repeat","content":"pub fn do_repeat(n: Int, input: a, fun: fn(a) -&gt; b) -&gt; Nil\n\nSynonyms:\ngleamy_bench.do_repeat\ngleamy_bench do_repeat","url":"gleamy_bench.html#do_repeat"},{"doc":"gleamy_bench","title":"repeat","content":"pub fn repeat(n: Int, fun: fn(a) -&gt; b) -&gt; fn(a) -&gt; Nil\n\nSynonyms:\ngleamy_bench.repeat\ngleamy_bench repeat","url":"gleamy_bench.html#repeat"},{"doc":"gleamy_bench","title":"run","content":"pub fn run(bench: Bench(a, b), options: List(Option)) -&gt; List(Set)\n\nSynonyms:\ngleamy_bench.run\ngleamy_bench run","url":"gleamy_bench.html#run"},{"doc":"gleamy_bench","title":"table","content":"pub fn table(sets: List(Set), stats: List(Stat)) -&gt; String\n\nSynonyms:\ngleamy_bench.table\ngleamy_bench table","url":"gleamy_bench.html#table"},{"doc":"gleamy_bench","title":"gleamy_bench","content":"","url":"gleamy_bench.html"},{"doc":"gleamy_bench_example","title":"main","content":"pub fn main() -&gt; Nil\n\nSynonyms:\ngleamy_bench_example.main\ngleamy_bench_example main","url":"gleamy_bench_example.html#main"},{"doc":"gleamy_bench_example","title":"gleamy_bench_example","content":"","url":"gleamy_bench_example.html"},{"doc":"test","title":"Ctrl","content":"pub type Ctrl(a) {\n  Pure(a)\n  Yield(\n    marker: String,\n    op: fn(fn(a) -&gt; Ctrl(a)) -&gt; Ctrl(a),\n    cont: fn(a) -&gt; Ctrl(a),\n  )\n}\n\nPure(a)\n\n\nYield(\n  marker: String,\n  op: fn(fn(a) -&gt; Ctrl(a)) -&gt; Ctrl(a),\n  cont: fn(a) -&gt; Ctrl(a),\n)\n\n\nSynonyms:\ntest.Ctrl\ntest Ctrl","url":"test.html#Ctrl"},{"doc":"test","title":"main","content":"pub fn main() -&gt; Nil\n\nSynonyms:\ntest.main\ntest main","url":"test.html#main"},{"doc":"test","title":"mprompt","content":"pub fn mprompt(marker: String, ctl: Ctrl(a)) -&gt; Ctrl(a)\n\nSynonyms:\ntest.mprompt\ntest mprompt","url":"test.html#mprompt"},{"doc":"test","title":"prompt","content":"pub fn prompt(marker: String, action: fn() -&gt; Ctrl(a)) -&gt; Ctrl(a)\n\nSynonyms:\ntest.prompt\ntest prompt","url":"test.html#prompt"},{"doc":"test","title":"yield","content":"pub fn yield(marker: String, op: fn(fn(a) -&gt; Ctrl(a)) -&gt; Ctrl(a)) -&gt; Ctrl(\n  a,\n)\n\nSynonyms:\ntest.yield\ntest yield","url":"test.html#yield"},{"doc":"test","title":"test","content":"","url":"test.html"}]);